@@ -58,7 +58,7 @@ class Libfuzzer(Command):
         colocate_all_tasks: bool = False,
         colocate_secondary_tasks: bool = True,
         check_fuzzer_help: bool = True,
-        expect_crash_on_failure: bool = True,
+        expect_crash_on_failure: bool = False,
         minimized_stack_depth: Optional[int] = None,
     ) -> None:
 
@@ -210,7 +210,7 @@ class Libfuzzer(Command):
         colocate_all_tasks: bool = False,
         colocate_secondary_tasks: bool = True,
         check_fuzzer_help: bool = True,
-        expect_crash_on_failure: bool = True,
+        expect_crash_on_failure: bool = False,
         minimized_stack_depth: Optional[int] = None,
     ) -> Optional[Job]:
         """
@@ -443,7 +443,7 @@ class Libfuzzer(Command):
         debug: Optional[List[TaskDebugFlag]] = None,
         ensemble_sync_delay: Optional[int] = None,
         check_fuzzer_help: bool = True,
-        expect_crash_on_failure: bool = True,
+        expect_crash_on_failure: bool = False,
     ) -> Optional[Job]:
 
         """
@@ -626,7 +626,7 @@ class Libfuzzer(Command):
         with tempfile.TemporaryDirectory() as tempdir:
             if sysroot:
                 setup_path = File(os.path.join(tempdir, "setup.sh"))
-                with open(setup_path, "w") as handle:
+                with open(setup_path, "w", newline="\n") as handle:
                     sysroot_filename = helper.target_exe_blob_name(sysroot, None)
                     handle.write(
                         "#!/bin/bash\n"
@@ -638,7 +638,7 @@ class Libfuzzer(Command):
                     )
 
                 wrapper_path = File(os.path.join(tempdir, wrapper_name))
-                with open(wrapper_path, "w") as handle:
+                with open(wrapper_path, "w", newline="\n") as handle:
                     handle.write(
                         "#!/bin/bash\n"
                         'SETUP_DIR=$(dirname "$(readlink -f "$0")")\n'
@@ -648,7 +648,7 @@ class Libfuzzer(Command):
                 upload_files = [setup_path, wrapper_path, sysroot]
             else:
                 setup_path = File(os.path.join(tempdir, "setup.sh"))
-                with open(setup_path, "w") as handle:
+                with open(setup_path, "w", newline="\n") as handle:
                     handle.write(
                         "#!/bin/bash\n"
                         "set -ex\n"
@@ -656,7 +656,7 @@ class Libfuzzer(Command):
                     )
 
                 wrapper_path = File(os.path.join(tempdir, wrapper_name))
-                with open(wrapper_path, "w") as handle:
+                with open(wrapper_path, "w", newline="\n") as handle:
                     handle.write(
                         "#!/bin/bash\n"
                         'SETUP_DIR=$(dirname "$(readlink -f "$0")")\n'
